@@ -12,4 +12,7 @@ from turf.great_circle import great_circle
 from turf.helpers import *
 from turf.length import length
 from turf.midpoint import midpoint
+from turf.rhumb_bearing import rhumb_bearing
+from turf.rhumb_destination import rhumb_destination
+from turf.rhumb_distance import rhumb_distance
 from turf.square import square
